# gpt-ask
A simple cli for open ai gpt toolbelt like inteactions

features:

 * code highlighting
 * code copy mode (ask /$X with X the snippet id) to show raw code
 * single command shot : `ask -c "hello world"`
 * context mode : start conversation | command with some context (ask --help for more information)
 
## install

`pip install gpt-ask`

write your gpt token in `~/.gkey`

## usage

run command

`ask`

then you are in.

![image](https://user-images.githubusercontent.com/5399780/230721999-782d5e31-f2c1-46b6-a8b0-56ee8b523ef2.png)

